import { ProTable, useTable } from '@uiw-admin/components';
export default function Demo() {
  const table = useTable('/api/getData', {
    // 格式化接口返回的数据，必须返回{total 总数, data: 列表数据}的格式
    formatData: data => {
      return {
        total: data.total,
        data: data.data
      };
    },
    // 格式化查询参数 会接收到pageIndex 当前页  searchValues 表单数据
    query: (pageIndex, pageSize, searchValues) => {
      return {
        page: pageIndex,
        pageSize,
        data: searchValues
      };
    }
  });
  return <ProTable
  // 操作栏按钮
  operateButtons={[{
    label: '自定义查询',
    type: 'primary'
  }, {
    label: '全部取消',
    onClick: () => {
      table.selection.unSelectAll();
    }
  }]}
  // 搜索栏按钮
  searchBtns={[{
    label: '搜索',
    type: 'primary',
    onClick: () => {
      table.onSearch();
    }
  }, {
    label: '重置',
    onClick: () => {
      table.onReset();
    }
  }]} table={table} onBeforeSearch={({
    current
  }) => {
    const errorObj = {};
    if (!current.name) errorObj.name = '名字不能为空！';
    if (Object.keys(errorObj).length > 0) {
      const err = new Error();
      err.filed = errorObj;
      throw err;
    }
    return true;
  }} rowSelection={{
    // 多选 checkbox 单选radio
    type: 'checkbox',
    // 选中的键名 column里的key
    selectKey: 'name',
    // 默认值
    defaultSelected: ['邓紫棋']
  }}
  // 取消全部选择
  onPageChange={() => {
    table.selection.unSelectAll();
  }} paginationProps={{
    pageSizeOptions: [10, 20, 30],
    pageSize: 10,
    onShowSizeChange: (current, pageSize) => {
      // console.log(current, pageSize)
    }
  }} columns={[{
    title: '名字',
    key: 'name',
    props: {
      widget: 'input',
      initialValue: 'zzz',
      key: 'name',
      // 组件属性
      widgetProps: {
        placeholder: '输入用户名'
      }
    }
  }, {
    title: '年龄',
    key: 'age',
    width: 50,
    props: {
      widget: 'select',
      option: [{
        label: '20',
        value: 20
      }, {
        label: '10',
        value: 10
      }]
    }
  }, {
    title: '地址',
    key: 'info',
    props: {
      label: '详细地址',
      key: 'detailAddress',
      widget: 'textarea'
    }
  }]} />;
}